eprllib.RewardFunctions.henderson_2024 — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.RewardFunctions.henderson_2024

## Henderson et al. (2024)

This module contains the reward function class for the EnergyPlusEnv_v0 environment. The reward function is based on the Henderson et al. (2024) paper, which proposes a reward function for optimizing the energy consumption and comfort of a building. The reward function is divided into two components: energy demand penalty and comfort penalty. The energy demand penalty is based on the maximum energy demand for the entire episode, and the comfort penalty is based on the average PPD comfort metric for the entire episode. The reward function is normalized by dividing each term by the maximum value for the entire episode, and multiplying by a ponderation factor for the energy and (1-beta) for the comfort. Both terms are negatives, representing a penalti for demand energy and for generate discomfort.

The reward function is designed to be used in conjunction with the EnergyPlusEnv_v0 environment, which provides the necessary information for calculating the reward.

Classes

`henderson_2024`(reward_fn_config) |